::: django_slack_tools.slack_messages.messenger
    options:
      show_root_heading: true

::: django_slack_tools.slack_messages.backends
    options:
      show_root_heading: true

::: django_slack_tools.slack_messages.middlewares
    options:
      show_root_heading: true

::: django_slack_tools.slack_messages.message_templates
    options:
      show_root_heading: true

::: django_slack_tools.slack_messages.template_loaders
    options:
      show_root_heading: true
